<?php

switch ($messaggio) {

case "Vedi le prenotazioni":  			$messaggio = "Voir les reservations"; break;
case "presenti dal":  					$messaggio = "présents de"; break;
case "al":  							$messaggio = "à"; break;
case "Senza colori":  					$messaggio = "Sans couleurs"; break;
case "Con colori":  					$messaggio = "Avec couleurs"; break;
case "Tabella prenotazioni precedenti al":  	$messaggio = "Tableau avec des réservations précédentes à"; break;
case "Tabella prenotazioni successive al":  	$messaggio = "Tableau avec des réservations suivantes"; break;
case "Tabella con tutte le prenotazioni":  		$messaggio = "Tableau avec toutes les réservations"; break;
case "Cognome_cliente":  				$messaggio = "Nom client"; break;
case "Data_iniziale":  					$messaggio = "Date début"; break;
case "Data_finale":  					$messaggio = "Date fin"; break;
case "sett":  							$messaggio = "S"; break;
case "gio":  							$messaggio = "J"; break;
case "Tariffa_completa":  				$messaggio = "Tarif complet"; break;
case "Caparra":  						$messaggio = "Accompte"; break;
case "Pagato":  						$messaggio = "Payé"; break;
case "Da_pagare":  						$messaggio = "A Payer"; break;
case "Commento":  						$messaggio = "Commentaire"; break;
case "Costo_uni.":  					$messaggio = "Cout simp"; break;
case "Costo_sett.":  					$messaggio = "Cout sema"; break;
case "Costo_gio.":  					$messaggio = "Cout jour"; break;
case "Soldi di prenotazioni cancellate":  	$messaggio = "Argent des réservations supprimées"; break;
case "Trasferito in cassa":  			$messaggio = "Transféré en caisse"; break;
case "RESTO":  							$messaggio = "RESTE"; break;
case "Sei sicuro di voler cancellare la spesa":	$messaggio = "Etes vous certain de vouloir supprimer paiement"; break;
case "del valore di":  					$messaggio = "de la valeur de"; break;
case "Sei sicuro di voler cancellare l'entrata":	$messaggio = "Etes vous certain de vouloir supprimer encaissement"; break;
case "SI":  							$messaggio = "OUI"; break;
case "NO":  							$messaggio = "NON"; break;
case "Entrata o spesa":  				$messaggio = "Paiement en espèces ou reçu"; break;
case "cacellata":  						$messaggio = "supprimez"; break;
case "Costo o spesa già cancellati":  	$messaggio = "Paiements ou encaissements déjà supprimé"; break;
case "Natura_spesa":  					$messaggio = "Nature du paiement"; break;
case "Importo":  						$messaggio = "Valeur"; break;
case "Inserita_da":  					$messaggio = "données insérées "; break;
case "Data_di_inserimento":  			$messaggio = "Date d'insertion"; break;
case "Cancella":  						$messaggio = "Supprimez"; break;
case "Natura_entrata":  				$messaggio = "Nature du reçu"; break;
case "cancella":  						$messaggio = "supprimez"; break;
case "entrata presa dalle prenotazioni":  	$messaggio = "Reçu en espèces pris des réservations"; break;
case "Inserisci nuove spese o entrate":  	$messaggio = "Insérez les nouveaux paiements ou encaissements"; break;
case "Storia entrate-uscite prenotazioni":  	$messaggio = "Historique des paiements de réservations"; break;
case "Sei sicuro di voler cancellare il costo aggiuntivo":	$messaggio = "Etes vous certain de vouloir effacer le surcoût"; break;
case "Il costo aggiuntivo":  			$messaggio = "Le surcoût suppémentaire"; break;
case "Il costo aggiuntivo è cambiato nel frattempo, non è stato cancellato":	$messaggio = "Le surcoût a été changé en attendant, il n'a pas été supprimé"; break;
case "è stato cancellato":  			$messaggio = "a été supprimé"; break;
case "I periodi sono stati aggiunti fino al":  	$messaggio = "Des périodes ont été ajoutées jusque à"; break;
case "Tabella con periodi e relative tariffe del":	$messaggio = "Tableau avec les périodes et les prix respectifs de"; break;
case "tariffa":  						$messaggio = "tarif"; break;
case "Inizio_settimana":  				$messaggio = "Semaine début"; break;
case "Inizio_giorno":  					$messaggio = "Semaine début"; break;
case "Fine_settimana":  				$messaggio = "Semaine fin"; break;
case "Fine_giorno":  					$messaggio = "Jour début"; break;
case "Aggiungi periodi":  				$messaggio = "Ajoutez les périodes"; break;
case "fino al mese":  					$messaggio = "jusqu'au mois"; break;
case "Tabella con i costi aggiuntivi del":  	$messaggio = "Tableau avec des surcoûts de"; break;
case "Nome":  							$messaggio = "Prénom"; break;
case "Prezzo":  						$messaggio = "Prix"; break;
case "Da_assegnare":  					$messaggio = "À attribuer"; break;
case "finale":  						$messaggio = "unique"; break;
case "Sempre":  						$messaggio = "Toujours"; break;
case "Su_richiesta":  					$messaggio = "On demande"; break;
case "chidere_per_quanto_moltiplicare":  	$messaggio = "demandez par combien multiplié"; break;
case "cosiderare_come_letti_aggiuntivi":  	$messaggio = "considérez comme lits supplémentaires"; break;
case "settimanale":  					$messaggio = "hebdomadaire"; break;
case "giornaliero":  					$messaggio = "journalier"; break;
case "tutte":  							$messaggio = "toutes"; break;
case "tutti":  							$messaggio = "tous"; break;
case "_le":  							$messaggio = " les"; break;
case "_i":  							$messaggio = " le"; break;
case "_settimane":  					$messaggio = " semaines"; break;
case "_giorni":  						$messaggio = " jours"; break;
case "_meno_una":  						$messaggio = " moins une"; break;
case "con_n°_di_settimane":  			$messaggio = "demander le nombre de semaines"; break;
case "con_n°_di_giorni":  				$messaggio = "demander le nombre de jours"; break;
case "_da_chiedere":  					$messaggio = " à demander"; break;
case "percentuale":  					$messaggio = "pourcentage"; break;
case "% arrotondato_a_":  				$messaggio = "% arrondi à "; break;
case "Vai alla pagina di inserzione prezzi":  	$messaggio = "Allez à la page d'insertion des prix"; break;
case "chiamati":  						$messaggio = "appelé"; break;
case "Tabella con tutti i clienti":  	$messaggio = "Tableau avec tous les clients"; break;
case "pag. prec.":  					$messaggio = "page précédente"; break;
case "pag. succ.":  					$messaggio = "page suivante"; break;
case "Cognome":  						$messaggio = "Nom"; break;
case "Nome":  							$messaggio = "Prénom"; break;
case "Telefono":  						$messaggio = "Téléphone"; break;
case "Indirizzo":  						$messaggio = "Adresse"; break;
case "Città":  							$messaggio = "Ville"; break;
case "Nazione":  						$messaggio = "Pays"; break;
case "CAP":  							$messaggio = "CP"; break;
case "Fax":  							$messaggio = "Fax"; break;
case "Data_di_nascita":  				$messaggio = "Date de nais"; break;
case "2°telefono":  					$messaggio = "2° tél"; break;
case "Commento":  						$messaggio = "Commentaire"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 2 per la":	$messaggio = "Etes vous certain de vouloir <b>supprimer</b> la règle d'attribution 2 pour"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 3 per la":	$messaggio = "Etes vous certain de vouloir <b>supprimer</b> la règle d'attribution 3 pour"; break;
case "La regola di assegnazione è stata cancellata":	$messaggio = "La règle d'attribution a été supprimée"; break;
case "La regola di assegnazione è già stata cancellata":	$messaggio = "La règle d'attribution a déjà été supprimée"; break;
case "Tabella con le regole di assegnazione":	$messaggio = "Tableau avec les règles d'attribution"; break;
case "del":					$messaggio = "de"; break;
case "Tariffa":  				$messaggio = "Tarif"; break;
case "Inserisci nuove regole":  		$messaggio = "Insérez une nouvelle règle"; break;
case "Il numero inserito esiste già":  		$messaggio = "Le numéro inséré existe déjà"; break;
case "Continua":  				$messaggio = "Continuez"; break;
case "Torna indietro":  			$messaggio = "Retournez"; break;
case "Casa":  					$messaggio = "Maison"; break;
case "Piano":  					$messaggio = "Etage"; break;
case "Capienza_massima":  			$messaggio = "Capacité maximum"; break;
case "Priorità":  				$messaggio = "Priorité"; break;
case "Modifica":  				$messaggio = "Modifiez"; break;
case "modifica":  				$messaggio = "modifiez"; break;
case "Torna al menù principale":  		$messaggio = "Retour au menu principal"; break;
case "persone":  				$messaggio = "personnes"; break;
case "s":  					$messaggio = "s"; break;
case "g":  					$messaggio = "j"; break;
case "Mostra":  				$messaggio = "Affichage"; break;
case "Non_mostrare":  				$messaggio = "Ne montrez pas"; break;
case "Regole":  				$messaggio = "Règles"; break;
case "Tariffe abbinate":  			$messaggio = "Prix associés"; break;
case "Verranno effettuati i seguenti cambiamenti":	$messaggio = "Les changements suivants seront effectués"; break;
case "I soldi pagati per la prenotazione":  	$messaggio = "L'argent payé pour la réservation"; break;
case "a nome di":  				$messaggio = "Au nom de Mr/Mad"; break;
case "verranno cambiati da":  			$messaggio = "sera changé de"; break;
case "a":  					$messaggio = "à"; break;
case "Le prenotazioni <b>non sono state modificate</b> perchè sono cambiate nel frattempo":	$messaggio = "Les réservations <b>n'ont pas été modifiées</b> parce que la table de réservations a changé entre-temps"; break;
case "tutto pagato":  				$messaggio = "tout est payé"; break;
case "caparra pagata":  			$messaggio = "acompte"; break;
case "pagato niente":  				$messaggio = "rien n'est payé"; break;
case "di":  					$messaggio = "de"; break;
case "la conferma":  				$messaggio = "confirmé"; break;
case "La prenotazione":  			$messaggio = "La réservation"; break;
case "verrà confermata":  			$messaggio = "sera confirmé"; break;
case "Data di inserimento":  			$messaggio = "Date d'insertion"; break;
case "Calcola il subtotale delle prenotazioni selezionate":	$messaggio = "Calculez le total partiel des réservations choisies"; break;
case "selezionate precedentemente":  		$messaggio = "précédemment choisi"; break;
case "Saldo totale":  				$messaggio = "Différence totale"; break;
case "l'anno":  				$messaggio = "l'an"; break;
case "dal database":  				$messaggio = "de la base de données"; break;
case "verranno <b>cancellati</b>":  		$messaggio = "sera <b>supprimé</b>"; break;
case "L'anno":  				$messaggio = "L'an"; break;
case "è stato cancellato dal batabase":  	$messaggio = "a été supprimé de la base de données"; break;
case "Non è stato possibile cancellare l'anno":	$messaggio = "Il n'a pas été possible de supprimer l'année"; break;
case "dal database, controllare i permessi sulla cartella dati":	$messaggio = "de la base de données, vérifiez les permissions sur le fichier de dati"; break;
case "Utente":  				$messaggio = "Utilisateur"; break;
case "Periodi_permessi":  			$messaggio = "Periodes_autorisees"; break;
case "unico":  					$messaggio = "unique"; break;
case "fisso":  					$messaggio = "fixe"; break;
case "percentuale su tariffa":  		$messaggio = "pourcentage du prix"; break;
case "percentuale su totale":  			$messaggio = "pourcentage du total"; break;
case "varia_con_la_prenotazione":  		$messaggio = "changements_avec_la_reservation"; break;
case "non_varia_con_la_prenotazione":  		$messaggio = "ne_change_pas_avec_la_reservation"; break;
case "_meno_l'ultima":  			$messaggio = "_moins_la_derniere"; break;
case "_meno_l'ultimo":  			$messaggio = "_moins_le_dernier"; break;
case "_meno_la_prima":  			$messaggio = "_moins_la_premiere"; break;
case "_meno_il_primo":  			$messaggio = "_moins_le_premier"; break;
case "giorni":  				$messaggio = "jours"; break;
case "moltiplicare_per_persone":  		$messaggio = "multiplier_par_personne"; break;
case "moltiplicare_per_persone_totali":  	$messaggio = "multiplier_par_total_personne"; break;
case "moltiplicare_per_1":  			$messaggio = "multiplier_par_1"; break;
case "_nella_stessa_settimana":  		$messaggio = "_dans_la_meme_semaine"; break;
case "_nello_stesso_giorno":  			$messaggio = "_dans_le_meme_jour"; break;
case "Prenotazione intera in":  		$messaggio = "Réservation entière dans"; break;
case "Parte della prentoazione in":  		$messaggio = "Une partie de réservation dans"; break;
case "Solo settimane della prenotazione in":  	$messaggio = "Seulement les semaines de la réservation dans"; break;
case "Solo giorni della prenotazione in":  	$messaggio = "Seulement les jours de la réservation dans"; break;
case " o ":  					$messaggio = " ou "; break;
case " a ":  					$messaggio = " à "; break;
case "_si":  					$messaggio = "_oui"; break;
case "_no":  					$messaggio = "_no"; break;
case "_e_":  					$messaggio = "_et_"; break;
case "associato_a_settimane_specifiche":  	$messaggio = "associe_aux_semaines_specifiques"; break;
case "non_associato_a_settimane_specifiche":  	$messaggio = "non_associé_aux_semaines_specifiques"; break;
case "associato_a_giorni_specifici":  		$messaggio = "associe_aux_jours_specifiques"; break;
case "non_associato_a_giorni_specifici":  	$messaggio = "non_associe_aux_jours_specifiques"; break;
case "modifica con prenotazione":  		$messaggio = "modifiez avec la réservation"; break;
case "percentuale su caparra":  		$messaggio = "pourcentage de d'acompte"; break;
case "percentuale su resto caparra":  		$messaggio = "pourcentage de différence sur reste acompte"; break;
case "Cancellati":  				$messaggio = "Supprimer"; break;
case "OK":  					$messaggio = "OK"; break;
case "Annulla":  				$messaggio = "Annulez"; break;
case "Cancella i clienti senza prenotazioni":	$messaggio = "Supprimez les clients sans réservations"; break;
case "Metodo pagamento":  			$messaggio = "Méthode paiement"; break;
case "del":  					$messaggio = "de"; break;
case "Modifica tutti i campi della tabella":  	$messaggio = "Modifiez tous les champs de la table"; break;
case "Applica i cambiamenti":  			$messaggio = "Appliquez les changements"; break;
case "aggiungi":  				$messaggio = "add"; break;
case "Beni inventario":  			$messaggio = "Inventory goods"; break;
case "in":  					$messaggio = "in"; break;
case "giorno":  				$messaggio = "day"; break;
case "p":  					$messaggio = "p"; break;
case "Aggiungi":  				$messaggio = "Add"; break;
case "e":  					$messaggio = "and"; break;
case "Id":  					$messaggio = "Id"; break;
case "chiedere":  				$messaggio = "ask"; break;
case "Visualizza Tabelle":  			$messaggio = "View Tables"; break;
case "Pers.":  					$messaggio = "Peop."; break;
case "TOTALE":  				$messaggio = "TOTAL"; break;
case "Tutte le spese del":  			$messaggio = "All expenses of"; break;
case "nella cassa principale":  		$messaggio = "in main cashbox"; break;
case "Tutte le entrate del":  			$messaggio = "All incomes of"; break;
case "Tipo":  					$messaggio = "Type"; break;
case "Caparre, commissioni e tasse del":  	$messaggio = "Deposits, commissions and taxes of"; break;
case "Arrotondato_a":  				$messaggio = "Rounded_to"; break;
case "Cerca i clienti con cognome o email":  	$messaggio = "Search clients with surname or email"; break;
case "Email":  					$messaggio = "Email"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 1 per la":	$messaggio = "Are you sure you want to <b>delete</b> the assignment rule 1 for"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 4 per la":	$messaggio = "Are you sure you want to <b>delete</b> the assignment rule 4 for"; break;
case "Motivazione":  				$messaggio = "Motivation"; break;
case "pagine":  				$messaggio = "pages"; break;
case "saldo":  					$messaggio = "difference"; break;
case "porre per le prenotazioni selezionate":  	$messaggio = "selected reservations to"; break;
case "cambia":  				$messaggio = "change"; break;
case "pagina":  				$messaggio = "page"; break;
case "<b style=\"color: red;\">ATTENZIONE</b>: premendo su <b>\"<i>Continua</i>\"</b>, tutti i dati riguardanti l'anno":	$messaggio = "<b style=\"color: red;\">WARNING</b>: if you press <b>\"<i>Continue</i>\"</b>, all data regarding year"; break;
case "Profilo":  				$messaggio = "Profile"; break;
case "Cliente":  				$messaggio = "Client"; break;
case "cliente":  				$messaggio = "client"; break;
case "massimo_":  				$messaggio = "maximum_"; break;
case "clienti":  				$messaggio = "clients"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\"><b>cancellare":	$messaggio = "Are you sure you want to <div style=\"display: inline; color: red;\"><b>delete"; break;
case "clienti</b></div> che non sono associati a nessuna prenotazione e nessun pagamento":	$messaggio = "clients</b></div> that don't have any associated reservation or payment"; break;
case "carte di credito</b></div> associate a clienti che non hanno nessuna prenotazione nel futuro e nessuna prenotazione non pagata":	$messaggio = "credit cards</b></div> from clients without reservations in the future and without unpaid reservations"; break;
case "Tariffe":  				$messaggio = "Rates"; break;
case "Modifica i campi della tabella":  	$messaggio = "Modify table fields"; break;
case "documento di tipo":  			$messaggio = "document type"; break;
case "visualizza":  				$messaggio = "view"; break;
case "Vedi tutte le prenotazioni":  		$messaggio = "View all reservations"; break;
case "Numero di persone":  			$messaggio = "Number of people"; break;
case "assegna_se_":  				$messaggio = "assign_if_"; break;
case "più_di_":  				$messaggio = "less_than_"; break;
case "meno_di_":  				$messaggio = "more_than_"; break;
case "_giorni_da_inizio":  			$messaggio = "_days_from_beginning"; break;
case "assegna_con_":  				$messaggio = "assign_with_"; break;
case "_o_più_prenotazioni":  			$messaggio = "_or_more_reservations"; break;
case "Modifica i prezzi":  			$messaggio = "Modify prices"; break;
case "<div style=\"display: inline; color: red;\">Non</div> è stato possibile inserire alcuni prezzi":	$messaggio = "It was <div style=\"display: inline; color: red;\">not</div> possible to insert some prices"; break;
case "I prezzi sono stati aggiornati":  	$messaggio = "The prices have been updated"; break;
case "Tutte le prenotazioni":  			$messaggio = "All reservations"; break;
case "Solo arrivi":  				$messaggio = "Only arrivals"; break;
case "Solo partenze":  				$messaggio = "Only departures"; break;
case "dal":  					$messaggio = "from"; break;
case "Vedi":  					$messaggio = "View"; break;
case "Tabella con tutti gli arrivi":  		$messaggio = "Table with all the arrivals"; break;
case "Tabella con tutte le partenze":  		$messaggio = "Table with all the departures"; break;
case "prova ad importare i prezzi":  		$messaggio = "try to import prices"; break;
case "giornalmente":  				$messaggio = "daily"; break;
case "settimanalmente":  			$messaggio = "weekly"; break;
case "Origine":  				$messaggio = "Origin"; break;
case "Modifica come gruppo le prenotazioni mostrate in tabella":	$messaggio = "Modify reservations shown in table as a group"; break;
case "Modifica come gruppo le prenotazioni selezionate":	$messaggio = "Modify selected reservations as a group"; break;
case "Statistiche":  				$messaggio = "Statistics"; break;
case "Anni":  					$messaggio = "Years"; break;
case "Numero di prenotazioni per mese":  	$messaggio = "Number of reservations per month"; break;
case "Entrate dalle prenotazioni per mese":  	$messaggio = "Incomes from reservations per month"; break;
case "Entrate progressive dalle prenotazioni":	$messaggio = "Progressive incomes from reservations"; break;
case "Numero di prenotazioni per origine":  	$messaggio = "Number of reservations per origin"; break;
case "Entrate dalle prenotazioni per origine":	$messaggio = "Incomes from reservations per origin"; break;
case "Cambia":  				$messaggio = "Change"; break;
case "Mesi":  					$messaggio = "Months"; break;
case "Entrate per metodo di pagamento":  	$messaggio = "Incomes per payment method"; break;
case "Descrizione":  				$messaggio = "Description"; break;
case "magazzino":  				$messaggio = "stockroom"; break;
case "inventario":  				$messaggio = "inventory"; break;
case "Codice":  				$messaggio = "Code"; break;
case "Mancanti":  				$messaggio = "Missing"; break;
case "bene eliminato":  			$messaggio = "item deleted"; break;
case "bene aggiunto":  				$messaggio = "item added"; break;
case "magazzino eliminato":  			$messaggio = "stockroom deleted"; break;
case "magazzino aggiunto":  			$messaggio = "stockroom added"; break;
case "Inventario importato":  			$messaggio = "Inventory imported"; break;
case "Importa l'invetario":  			$messaggio = "Import inventory"; break;
case "dal magazzino":  				$messaggio = "from stockroom"; break;
case "Incompatibilità":  			$messaggio = "Incompatibilities"; break;
case "raggruppa":  				$messaggio = "group"; break;
case "con email":  				$messaggio = "with email"; break;
case "Importa":  				$messaggio = "Import"; break;
case "per persona":  				$messaggio = "per person"; break;
case "con meno di":  				$messaggio = "with less than"; break;
case "dall'inizio":  				$messaggio = "from beginning"; break;
case "dalla fine":  				$messaggio = "from ending"; break;
case "Mostra solo tariffe selezionate":  	$messaggio = "Show only selected rates"; break;
case "mostra prezzi settimanali":  		$messaggio = "show weekly prices"; break;
case "mostra prezzi giornalieri":  		$messaggio = "show daily prices"; break;
case "periodi di":  				$messaggio = "periods of"; break;
case "Valore":  				$messaggio = "Value"; break;
case "della tariffa":  				$messaggio = "of rate"; break;
case "piano":  					$messaggio = "floor"; break;
case "casa":  					$messaggio = "house"; break;
case "documento":  				$messaggio = "document"; break;
case "documenti salvati":  			$messaggio = "saved documents"; break;
case "numero":  				$messaggio = "number"; break;
case "nome file":  				$messaggio = "filename"; break;
case "prenotazioni":  				$messaggio = "reservations"; break;
case "azione":  				$messaggio = "action"; break;
case "anno":  					$messaggio = "year"; break;
case "elimina":  				$messaggio = "delete"; break;
case "fai l'upload del documento numero":  	$messaggio = "upload document number"; break;
case "fai l'upload":  				$messaggio = "upload"; break;
case "si è sicuri di voler <b class=\"colred\">cancellare</b> il documento":	$messaggio = "Are you sure you want to <b class=\"colred\">delete</b> document"; break;
case "cancellato":  				$messaggio = "deleted"; break;
case "inviato":  				$messaggio = "uploaded"; break;
case "Commissioni":  				$messaggio = "Commissions"; break;
case "Tasse":  					$messaggio = "Taxes"; break;
case "senza_commissioni":  			$messaggio = "without_commissions"; break;
case "Documenti_salvati":  			$messaggio = "Saved_documents"; break;
case "TASSE":  					$messaggio = "TAXES"; break;
case "resto":  					$messaggio = "rest"; break;
case "cancella_periodi":  			$messaggio = "delete_periods"; break;
case "Sei sicuro di voler cancellare le commissioni dal":	$messaggio = "Are you sure you want to delete commissions from"; break;
case "sulla tariffa":  				$messaggio = "on rate"; break;
case "Le commissioni sono state cancellate":  	$messaggio = "Commissions have been deleted"; break;
case "Le commissioni sono cambiate nel frattempo, non sono state cancellate":	$messaggio = "Commissions have changed meanwhile, they have not been deleted"; break;
case "settimana":  				$messaggio = "week"; break;
case "costi agg.":  				$messaggio = "extra costs"; break;
case "sconto":  				$messaggio = "discount"; break;
case "Numero di prenotazioni per nazionalità del cliente titolare":	$messaggio = "Number of reservations per nationality of titular client"; break;
case "Entrate dalle prenotazioni per nazionalità del cliente titolare":	$messaggio = "Incomes from reservations per nationality of titular client"; break;
case "Prezzi con":  				$messaggio = "Prices with"; break;
case "Prenotazioni anno corrente":  		$messaggio = "Current year reservations"; break;
case "con prenotazioni inserite":  		$messaggio = "with reservations inserted"; break;
case "fino al":  				$messaggio = "until"; break;
case "nella cassa chiamata":  			$messaggio = "in the cashbox called"; break;
case "Totale nella cassa principale":  		$messaggio = "Total in main cashbox"; break;
case "Totale nella cassa":  			$messaggio = "Total in cashbox"; break;
case "Nuova cassa chiamata":  			$messaggio = "New cashbox called"; break;
case "Crea":  					$messaggio = "Create it"; break;
case "Una cassa chiamata":  			$messaggio = "A cashbox called"; break;
case "è stata creata":  			$messaggio = "has been created"; break;
case "Cassa chiamata":  			$messaggio = "Cashbox called"; break;
case "La cassa chiamata":  			$messaggio = "The cashbox called"; break;
case "è stata cancellata":  			$messaggio = "has been deleted"; break;
case "Eventuali entrate e spese presenti in cassa non sono state cancellate":	$messaggio = "Any incomes and expenses present in this cashbox have not been deleted"; break;
case "Modifica i beni già inseriti":  		$messaggio = "Modify already inserted items"; break;
case "Modifica i beni":  			$messaggio = "Modify items"; break;
case "I beni sono stati modificati":  		$messaggio = "The items have been modified"; break;
case "e combina":  				$messaggio = "and combine"; break;
case "percentuale su fisso della tariffa":	$messaggio = "percentage of fixed rate"; break;
case "percentuale su una persona della tariffa":	$messaggio = "percentage of one person of the rate"; break;
case "non più di":  				$messaggio = "no more than"; break;
case "non più del numero di persone":  		$messaggio = "no more than the number of people"; break;
case "non più del numero totale di persone":  	$messaggio = "no more than the total number of people"; break;
case "meno":  					$messaggio = "minus"; break;
case "aggiungendo":  				$messaggio = "adding"; break;
case "più di":  				$messaggio = "more than"; break;
case "prezzi importati":  			$messaggio = "prices imported"; break;
case "dalla tariffa":  				$messaggio = "from rate"; break;
case "Cancella le carte di credito di prenotazioni passate":	$messaggio = "Delete credit cards of past reservations"; break;
case "password per le carte di credito":  	$messaggio = "password for credit cards"; break;
case "Cancellate":  				$messaggio = "Deleted"; break;
case "carte di credito":  			$messaggio = "credit cards"; break;
case "password errata":  			$messaggio = "wrong password"; break;
case "Creare":  				$messaggio = "Create"; break;
case "persona":  				$messaggio = "person"; break;
case "chiusa":  				$messaggio = "closed"; break;
case "presenti in data":  			$messaggio = "present on"; break;
case "comprese partenze":  			$messaggio = "including departures"; break;
case "escludere_da_totale_percentuale":  	$messaggio = "exclude_from_percentage_total"; break;
case "da varie tariffe":  			$messaggio = "from different<br>rates"; break;
case "senza letti aggiuntivi":  		$messaggio = "without extra beds"; break;
case "Premere per modificare":  		$messaggio = "Click to modify"; break;
case "Converti definitivamente in":  		$messaggio = "Permanently convert into"; break;
case "al cambio attuale":  			$messaggio = "at current exchange rate"; break;
case "Le altre valute presenti nella cassa":  	$messaggio = "Other currencies in cashbox"; break;
case "sono state convertite in":  		$messaggio = "have been converted into"; break;
case "Tabella con le prenotazioni cancellate":	$messaggio = "Table with deleted reservations"; break;
case "<b>non importare</b> i prezzi":  		$messaggio = "<b>do not import</b> prices"; break;
case "Attenzione":  				$messaggio = "Notice"; break;
case "i periodi aggiunti non potranno più essere eliminati":	$messaggio = "periods added now can't be deleted later"; break;
case "come tipo di persona":  			$messaggio = "as person type"; break;
case "e applica la % del tipo di persona":  	$messaggio = "and apply the % of person type"; break;
case "escludendo":  				$messaggio = "excluding"; break;
case "includendo solo":  			$messaggio = "including only"; break;
case "Superato il massimo numero di anni comparabili":	$messaggio = "Exceeded the maximum number of comparable years"; break;
case "Numero_predefinito di persone":  		$messaggio = "Default_number of people"; break;
case "Numero_minimo di persone":  		$messaggio = "Minimum_number of people"; break;
case "Cancellare anche":  			$messaggio = "Delete also"; break;
case "clienti con solo prenotazioni cancellate negli anni passati, cancellando le loro prenotazioni in modo permanente":	$messaggio = "clients with only deleted reservations in past years, deleting their reservations permanently"; break;
case "Prenotazioni cancellate":  		$messaggio = "Deleted reservations"; break;
case "Anche cancellate":  			$messaggio = "Also deleted"; break;
case "Solo cancellate":  			$messaggio = "Only deleted"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
